<?php

declare(strict_types = 1);

namespace Drupal\Tests\paragraphs_usage\Functional;


/**
 * Test paragraphs usage.
 *
 * @group paragraphs_usage
 */
class ParagraphsUsageTest extends ParagraphsUsageTestBase {

  /**
   * Modules to enable.
   *
   * @var array
   */
  public static $modules = [
    'paragraphs',
    'user',
    'system',
    'node',
    'field',
    'field_ui',
    'entity_reference',
    'entity_reference_revisions',
    'paragraphs_usage',
    'block',
  ];

  /**
   * {@inheritdoc}
   */
  protected function setUp(): void {
    parent::setUp();
    $this->loginAsAdmin();
  }

  /**
   * Check if paragraph is used in article content type.
   */
  public function testCheckIfUsed() {
    $this->createContentType([
      'type' => 'article',
      'name' => 'article',
    ]);
    $this->addParagraphsType('test_paragraphs');
    $this->addParagraphsField('article', 'test_paragraphs', 'node');

    // Create a reference to an article.
    $this->fieldUIAddNewField('/admin/structure/types/manage/article', 'test_paragraphs', 'test_paragraphs', 'entity_reference_revisions', [
      'cardinality' => 'number',
      'cardinality_number' => 1,
      'settings[target_type]' => 'paragraph',
    ], [
      'settings[handler_settings][target_bundles_drag_drop][test_paragraphs][enabled]' => TRUE,
    ]);

    $this->drupalGet('admin/structure/paragraphs_type/test_paragraphs/usage');
    $this->assertSession()->pageTextContains('article');

  }

  /**
   * Check if paragraph is not used in page content type.
   */
  public function testCheckIfNotUsed() {
    $this->createContentType([
      'type' => 'article',
      'name' => 'article',
    ]);
    $this->createContentType([
      'type' => 'page',
      'name' => 'page',
    ]);

    $this->addParagraphsType('test_paragraphs');
    $this->addParagraphsField('article', 'test_paragraphs', 'node');

    // Create a reference to an article.
    $this->fieldUIAddNewField('/admin/structure/types/manage/article', 'test_paragraphs', 'test_paragraphs', 'entity_reference_revisions', [
      'cardinality' => 'number',
      'cardinality_number' => 1,
      'settings[target_type]' => 'paragraph',
    ], [
      'settings[handler_settings][target_bundles_drag_drop][test_paragraphs][enabled]' => TRUE,
    ]);

    $this->drupalGet('admin/structure/paragraphs_type/test_paragraphs/usage');
    $this->assertSession()->pageTextNotContains('page');
  }

  /**
   * Check if paragraph is not used in any content type.
   */
  public function testCheckIsEmpty() {
    $this->createContentType([
      'type' => 'article',
      'name' => 'article',
    ]);
    $this->addParagraphsType('test_paragraphs');

    $this->drupalGet('admin/structure/paragraphs_type/test_paragraphs/usage');
    $this->assertSession()->pageTextContains('This paragraph is not used in any content type.');
  }

  /**
   * Check if paragraph don't exist.
   */
  public function testCheckIfParagraphDontExist() {

    $this->drupalGet('admin/structure/paragraphs_type/test_paragraphs/usage');
    $this->assertSession()->statusCodeEquals(404);
  }

}
